package Convos::Command::upgrade;

=head1 NAME

Convos::Command::upgrade - DEPRECATED

=head1 METHODS

=head2 run

=cut

sub run {
  die "'Convos::Command::upgrade' is deprecated\n";
}

=head1 COPYRIGHT

Nordaaker

=head1 AUTHOR

Jan Henning Thorsen - C<jhthorsen@cpan.org>

=cut

1;
